@@ -1,6 +1,6 @@
 from typing import Dict, Tuple, Union
 from asf_search import ASFSearchOptions, ASFSession, ASFStackableProduct
-from asf_search.CMR.translate import try_parse_frame_coverage, try_parse_bool
+from asf_search.CMR.translate import try_parse_frame_coverage, try_parse_bool, try_parse_int
 
 class NISARProduct(ASFStackableProduct):
     """
@@ -10,17 +10,26 @@ class NISARProduct(ASFStackableProduct):
     """
     _base_properties = {
         **ASFStackableProduct._base_properties,
+        'frameNumber': {
+            'path': ['AdditionalAttributes', ('Name', 'FRAME_NUMBER'), 'Values', 0],
+            'cast': try_parse_int,
+        },  # Sentinel, ALOSm and NISAR product alt for frameNumber (ESA_FRAME)
         'pgeVersion': {'path': ['PGEVersionClass', 'PGEVersion']},
         'mainBandPolarization': {'path': ['AdditionalAttributes', ('Name', 'FREQUENCY_A_POLARIZATION'), 'Values']},
         'sideBandPolarization': {'path': ['AdditionalAttributes', ('Name', 'FREQUENCY_B_POLARIZATION'), 'Values']},
         'frameCoverage': {'path': ['AdditionalAttributes', ('Name', 'FULL_FRAME'), 'Values', 0], 'cast': try_parse_frame_coverage},
         'jointObservation': {'path': ['AdditionalAttributes', ('Name', 'JOINT_OBSERVATION'), 'Values', 0], 'cast': try_parse_bool},
         'rangeBandwidth': {'path': ['AdditionalAttributes', ('Name', 'RANGE_BANDWIDTH_CONCAT'), 'Values']},
+        'productionConfiguration': {'path': ['AdditionalAttributes', ('Name', 'PRODUCTION_PIPELINE'), 'Values', 0]},
+        'processingLevel': {'path': ['AdditionalAttributes', ('Name', 'PRODUCT_TYPE'), 'Values', 0]},
     }
     def __init__(self, args: Dict = {}, session: ASFSession = ASFSession()):
         super().__init__(args, session)
+        if self.properties.get('processingLevel') is None:
+            self.properties.pop('processingLevel', None)
 
         self.properties['additionalUrls'] = self._get_additional_urls()
+        self.properties['browse'] = [url for url in self._get_urls() if url.endswith('.png') or url.endswith('.jpg') or url.endswith('.jpeg')]
         self.properties['s3Urls'] = self._get_s3_uris()
 
         if self.properties.get('groupID') is None:
